==> nextcloud-15.0.5p1.tgz: nextcloud/apps/serverinfo/l10n/zh_CN.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU 信息不可用",
    "Load average" : "平均负载",
    "Last minute" : "上一分钟",
    "Memory info not available" : "内存信息不可用",
    "Total" : "总量",
    "Current usage" : "当前用量",
    "Users" : "用户",
    "Groups" : "分组",
    "Links" : "链接",
    "Federated sent" : "联合云发送",
    "Federated received" : "联合云接收",
    "Talk conversations" : "Talk 会话",
    "Last 24 hours" : "最近 24 小时",
    "Last 1 hour" : "最近 1 小时",
    "Last 5 mins" : "最近 5 分钟",
    "Copy" : "复制",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "使用 ⌘-C 复制。",
    "Press Ctrl-C to copy." : "使用 Ctrl-C 复制。",
    "Monitoring" : "监控器",
    "Monitoring app with useful server information" : "Monitoring app 监控有用的服务器信息",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的服务器信息，例如 CPU 负载、内存占用、硬盘占用、在线用户数等。",
    "CPU load" : "CPU 负载",
    "Memory usage" : "内存使用",
    "Active users" : "活跃用户",
    "Shares" : "共享",
    "Storage" : "存储",
    "Users:" : "用户：",
    "Files:" : "文件：",
    "Storages:" : "存储设备：",
    "Free Space:" : "剩余空间：",
    "Version:" : "版本：",
    "Apps installed:" : "已安装应用：",
    "Apps updates available:" : "可更新应用：",
    "PHP" : "PHP",
    "Memory Limit:" : "内存限制：",
    "Max Execution Time:" : "最大执行时间：",
    "Upload max size:" : "最大上传大小：",
    "Database" : "数据库",
    "Type:" : "类型：",
    "Size:" : "大小：",
    "External monitoring tool" : "外部监控工具",
    "You can connect an external monitoring tool by using this end point:" : "此地址可用于外部监控工具：",
    "Did you know?" : "您知道吗？",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "在 URL 最后附加 \"?format=json\" 参数可以获得 JSON 格式的结果！",
    "You can connect an external monitoring tool by using this end point: " : "您可以使用此链接接入外部监控工具："
},
"nplurals=1; plural=0;");

==> nextcloud-16.0.5.tgz: nextcloud/apps/serverinfo/l10n/zh_CN.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU 信息不可用",
    "Load average" : "平均负载",
    "Last minute" : "上一分钟",
    "Memory info not available" : "内存信息不可用",
    "Total" : "总量",
    "Current usage" : "当前用量",
    "Users" : "用户",
    "Groups" : "分组",
    "Links" : "链接",
    "Mails" : "邮件",
    "Federated sent" : "联合云发送",
    "Federated received" : "联合云接收",
    "Talk conversations" : "Talk 会话",
    "24 hours" : "24 小时",
    "1 hour" : "1 小时",
    "5 mins" : "5 分钟",
    "Copy" : "复制",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "使用 ⌘-C 复制。",
    "Press Ctrl-C to copy." : "使用 Ctrl-C 复制。",
    "System" : "系统",
    "Monitoring" : "监控器",
    "Monitoring app with useful server information" : "Monitoring app 监控有用的服务器信息",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的服务器信息，例如 CPU 负载、内存占用、硬盘占用、在线用户数等。",
    "Operating System" : "操作系统",
    "CPU" : "CPU",
    "Memory" : "内存",
    "Server time" : "服务器时间",
    "Uptime" : "运行时长",
    "Time Servers" : "时间服务器",
    "Load" : "负载",
    "Disk" : "磁盘",
    "Mount" : "挂载",
    "Filesystem" : "文件系统",
    "Size" : "大小",
    "Available" : "可用",
    "Used" : "已用",
    "You will get a notification once one of your disks is nearly full." : "当您的一个磁盘快满时您会收到通知。",
    "Files:" : "文件：",
    "Storages:" : "存储设备：",
    "Free Space:" : "剩余空间：",
    "Network" : "网络",
    "Hostname" : "主机名",
    "DNS" : "DNS",
    "Gateway" : "网关",
    "Status" : "状态",
    "Speed" : "速度",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "活跃用户",
    "Total users:" : "总用户：",
    "Shares" : "共享",
    "PHP" : "PHP",
    "Version:" : "版本：",
    "Memory Limit:" : "内存限制：",
    "Max Execution Time:" : "最大执行时间：",
    "Upload max size:" : "最大上传大小：",
    "Database" : "数据库",
    "Type:" : "类型：",
    "Size:" : "大小：",
    "External monitoring tool" : "外部监控工具",
    "You can connect an external monitoring tool by using this end point:" : "此地址可用于外部监控工具：",
    "Did you know?" : "您知道吗？",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "在 URL 最后附加 \"?format=json\" 参数可以获得 JSON 格式的结果！",
    "Last 24 hours" : "最近 24 小时",
    "Last 1 hour" : "最近 1 小时",
    "Last 5 mins" : "最近 5 分钟",
    "CPU load" : "CPU 负载",
    "Memory usage" : "内存使用",
    "Storage" : "存储",
    "Users:" : "用户：",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "已安装应用：",
    "Apps updates available:" : "可更新应用："
},
"nplurals=1; plural=0;");
